/* 
 * Mirai. Copyright (C) 2024 Vyn
 * This file is licensed under version 3 of the GNU General Public License (GPL-3.0-only)
 * The license can be found in the LICENSE file or at https://www.gnu.org/licenses/gpl-3.0.txt
 */

import QtQuick
import QtQuick.Window
import QtQuick.Controls
import QtQuick.Layouts
import Mirai

Window {
	id: root
    width: 640
    height: 480
    visible: true
    title: qsTr("Hello World")

	

	property string selectedView: "list"

	Backend {
		id: backend
	}

	Item {
		id: colorPalette
		property QtObject selected: MiraiColorPalette
	}

	function capitalize(str) {
		return str.charAt(0).toUpperCase() + str.slice(1)
	}

	function openSettings() {
		filesForm.reset()
		filesFormPopup.open()
	}

	function newTask() {
		taskForm.taskToEdit = undefined
		taskForm.taskToEditIndex = -1
		taskFormPopup.open()
	}

	function editTask(task, taskIndex) {
		taskForm.taskToEdit = task
		taskForm.taskToEditIndex = taskIndex
		taskFormPopup.open()
	}

	RowLayout {
        anchors.fill: parent
        spacing: 0
		
        Rectangle {
            color: MiraiColorPalette.pane
            Layout.preferredWidth: childrenRect.width + 20
            Layout.fillHeight: true

			SideMenu {
				anchors.top: parent.top
				anchors.bottom: parent.bottom
				anchors.left: parent.left
				anchors.margins: 10
			}
        }

        Rectangle {
            color: colorPalette.selected.background
            Layout.fillWidth: true
            Layout.fillHeight: true
			ColumnLayout {
				anchors.fill: parent
				anchors.margins: 10
				spacing: 16

				TabSelector {
					Layout.fillWidth: true
					Layout.preferredHeight: childrenRect.height
					
					tabs: [
						{
							label: "List",
							onClick: () => { root.selectedView = "list" },
							selected: root.selectedView === "list"
						},
						{
							label: "Calendar",
							onClick: () => { root.selectedView = "calendar" },
							selected: root.selectedView === "calendar"
						}
					]

				}

				AppButton {
					icon.source: "qrc:/qt/qml/Mirai/src/images/add.png"
					icon.color: colorPalette.selected.palette.green
					text: "Add task"
					onClicked: {
						root.newTask()
					}
				}

				Component {
					id: listViewComponent
					ListView {
						
					}
				}

				Component {
					id: calendarViewComponent
					CalendarView {
						
					}
				}

				Loader {
					sourceComponent: selectedView === "list" ? listViewComponent
					: selectedView === "calendar" ? calendarViewComponent 
					: undefined
					Layout.fillWidth: true
					Layout.fillHeight: true
				}

				Popup {
					id: filesFormPopup
					width: parent.width * 0.75
					implicitHeight: filesForm.height + padding * 2
					x: Math.round((parent.width - width) / 2)
        			y: Math.round((parent.height * 0.4) / 2)
					padding: 8
					background: Rectangle {
						border.color: colorPalette.selected.modalBorder
						border.width: 2
						color: colorPalette.selected.pane
						radius: 4
					}
					FilesForm {
						id: filesForm
						width: parent.width
					}
				}

				Popup {
					id: taskFormPopup
					width: parent.width * 0.75
					implicitHeight: taskForm.height + padding * 2
					x: Math.round((parent.width - width) / 2)
        			y: Math.round((parent.height * 0.4) / 2)
					padding: 8
					background: Rectangle {
						border.color: colorPalette.selected.modalBorder
						border.width: 2
						color: colorPalette.selected.pane
						radius: 4
					}
					TaskForm {
						id: taskForm
						width: parent.width
						onConfirmed: {
							taskFormPopup.close()
						}
					}
				}
			}
        }
    }
}
