/* 
 * Mirai. Copyright (C) 2024 Vyn
 * This file is licensed under version 3 of the GNU General Public License (GPL-3.0-only)
 * The license can be found in the LICENSE file or at https://www.gnu.org/licenses/gpl-3.0.txt
 */

import QtQuick
import QtQuick.Window
import QtQuick.Layouts
import Mirai

ColumnLayout {
	id: control
	spacing: 32
	QtObject {
		id: internal
		property date weekStartDate: {
			const firstDayOfTheWeek = 1 // 1 = Monday, hardcoded for now
			const date = new Date()
			let	firstDayOfTheWeekDelta = date.getDay() - firstDayOfTheWeek
			if (firstDayOfTheWeekDelta < 0) {
				firstDayOfTheWeekDelta += 7
			}
			date.setDate(date.getDate() - firstDayOfTheWeekDelta)
			return date
		}
	}

	RowLayout {
		spacing: 12
		Layout.fillWidth: true
		Layout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
		AppButton {
			text: "<"
		  	onClicked: {
				internal.weekStartDate.setDate(internal.weekStartDate.getDate() - 7)
		  	}
		}

		AppText {
			text: capitalize(internal.weekStartDate.toLocaleDateString(Qt.locale(), "MMMM"))
			verticalAlignment: Text.AlignVCenter
			horizontalAlignment: Text.AlignHCenter
			font.pointSize: 24
		}

		AppButton {
			text: ">"
			onClicked: {
				internal.weekStartDate.setDate(internal.weekStartDate.getDate() + 7)
		  	}
		}
	}
	RowLayout {
		spacing: 0

		Layout.fillWidth: true
		Layout.fillHeight: true

		ColumnLayout {
			Layout.fillHeight: true
			spacing: 0
			AppText {
				text: ""
			}
			Rectangle {
				color: "transparent"
				Layout.preferredWidth: childrenRect.width + 10
				Layout.fillHeight: true	
				Repeater {
					model: 23 // Skip 00:00
					AppText {
						text: `${index + 1}:00`
						y: (parent.height / 24 * (index + 1)) - (height / 2)
						verticalAlignment: Text.AlignVCenter
					}
				}
			}
		}

		Repeater {
			model: 7

		   	Rectangle {
				Layout.fillWidth: true
				Layout.fillHeight: true
				property date day: new Date(new Date(internal.weekStartDate).setDate(internal.weekStartDate.getDate() + index))
				color: "transparent"

				Rectangle {
					color: colorPalette.selected.calendarLines
					height: parent.height
					width: 1
					anchors.left: parent.left
				}
			
				ColumnLayout {
					anchors.fill: parent
					
					spacing: 0
					
					
					AppText {
						Layout.fillWidth: true
						text: capitalize(day.toLocaleDateString(Qt.locale(), "dddd dd"))
						verticalAlignment: Text.AlignVCenter
						horizontalAlignment: Text.AlignHCenter
					}

					Rectangle {
						color: "transparent"
						Layout.fillWidth: true
						Layout.fillHeight: true
						id: daysSurface
						property real hourHeight: daysSurface.height / 24

						Repeater {
							model: 23 // Skip 00:00
							Rectangle {
								color: colorPalette.selected.calendarLines
								height: 1
								width: daysSurface.width
								y: daysSurface.hourHeight * (index + 1)
							}
						}
						
						Repeater {
							model: backend.tasks.filter(task => {
								const date = new Date(internal.weekStartDate)
								date.setDate(internal.weekStartDate.getDate() + index)
								return task.date === date.toLocaleDateString(Qt.locale(), "yyyy-MM-dd")
							})
							
							Rectangle {
								property string name: modelData.text
								property int startTime: parseInt(modelData.startTime)
								property int endTime: parseInt(modelData.endTime)
								color: colorPalette.selected.calendarEvent
								anchors.right: parent.right
								anchors.left: parent.left
								anchors.rightMargin: 2
								anchors.leftMargin: 2
								radius: 4
								y: daysSurface.hourHeight * startTime
								height: (endTime - startTime) * daysSurface.hourHeight

								ColumnLayout {
									anchors.fill: parent
									anchors.margins: 8
									AppText {
										text: name
									}
									Item { Layout.fillHeight: true }
								}
							}
						}
						Rectangle {
							color: day.getFullYear() === new Date().getFullYear() &&
					day.getMonth() === new Date().getMonth() &&
					day.getDate() === new Date().getDate() ? colorPalette.selected.calendarCurrentTime : "transparent"
							height: 2
							width: parent.width
							y: daysSurface.hourHeight * (new Date().getHours() + (new Date().getMinutes() / 60))
						}
					}
				}
		   	}
		}
	}
}
